@@ -1,5 +1,5 @@
 """
-US phone numbers, using only libphonenumbers
+US phone numbers
 """
 import re
 
